==> haskell-tar-conduit-0.3.2-350-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-tar-conduit.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 tar-conduit
version:              0.3.2
visibility:           public
id:                   tar-conduit-0.3.2-DEYEdnSZpd42fakaEA7l19
key:                  tar-conduit-0.3.2-DEYEdnSZpd42fakaEA7l19
license:              MIT
maintainer:
    michael@snoyman.com, bartavelle@gmail.com, alexey@kuleshevi.ch

author:               Michael Snoyman
homepage:             https://github.com/snoyberg/tar-conduit#readme
synopsis:             Extract and create tar files using conduit for streaming
description:
    Please see README.md. This is just filler to avoid warnings.

category:             Data Conduit
abi:                  430cdb952ad9c6203a14fb6c856e33ed
exposed:              True
exposed-modules:      Data.Conduit.Tar Data.Conduit.Tar.Types
hidden-modules:       Data.Conduit.Tar.Unix
import-dirs:          /usr/lib/ghc-9.0.2/site-local/tar-conduit-0.3.2
library-dirs:         /usr/lib/ghc-9.0.2/site-local/tar-conduit-0.3.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-tar-conduit
hs-libraries:         HStar-conduit-0.3.2-DEYEdnSZpd42fakaEA7l19
depends:
    base-4.15.1.0 bytestring-0.10.12.1
    conduit-1.3.4.3-L6s3vcmYjoL7mwc4vSV1rf directory-1.3.6.2
    filepath-1.4.2.1 safe-exceptions-0.1.7.3-BbZAXGcuv3aD0WfEctV6iQ
    text-1.2.5.0 unix-2.7.2.2

haddock-interfaces:   /usr/share/doc/haskell-tar-conduit/html/tar-conduit.haddock
haddock-html:         /usr/share/doc/haskell-tar-conduit/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-tar-conduit-0.3.2-351-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-tar-conduit.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 tar-conduit
version:              0.3.2
visibility:           public
id:                   tar-conduit-0.3.2-I4aez2uQ8MtGRolvcOwEKz
key:                  tar-conduit-0.3.2-I4aez2uQ8MtGRolvcOwEKz
license:              MIT
maintainer:
    michael@snoyman.com, bartavelle@gmail.com, alexey@kuleshevi.ch

author:               Michael Snoyman
homepage:             https://github.com/snoyberg/tar-conduit#readme
synopsis:             Extract and create tar files using conduit for streaming
description:
    Please see README.md. This is just filler to avoid warnings.

category:             Data Conduit
abi:                  d80852fb398c1ddf828fcc4020d72421
exposed:              True
exposed-modules:      Data.Conduit.Tar Data.Conduit.Tar.Types
hidden-modules:       Data.Conduit.Tar.Unix
import-dirs:          /usr/lib/ghc-9.0.2/site-local/tar-conduit-0.3.2
library-dirs:         /usr/lib/ghc-9.0.2/site-local/tar-conduit-0.3.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-tar-conduit
hs-libraries:         HStar-conduit-0.3.2-I4aez2uQ8MtGRolvcOwEKz
depends:
    base-4.15.1.0 bytestring-0.10.12.1
    conduit-1.3.4.3-7850AKAUO1kCI5lKyzLnW1 directory-1.3.6.2
    filepath-1.4.2.1 safe-exceptions-0.1.7.3-9THH0mIdiqjIrIB0ArIwvp
    text-1.2.5.0 unix-2.7.2.2

haddock-interfaces:   /usr/share/doc/haskell-tar-conduit/html/tar-conduit.haddock
haddock-html:         /usr/share/doc/haskell-tar-conduit/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
